from datetime import datetime, timedelta
from osinacore.models import Connection

class OnlineConnectionMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        # Call the view function or next middleware in the stack
        response = self.get_response(request)

        # If user is authenticated, create or update the Connection instance
        if request.user.is_authenticated:
            current_datetime = datetime.now()

            thirty_minutes_ago = current_datetime - timedelta(minutes=30)

            # Check if an online Connection instance exists within the last 30 minutes
            existing_connection = Connection.objects.filter(
                user=request.user,
                date__gte=thirty_minutes_ago,
                status='Online'
            ).first()

            # If there is no online connection within the last 30 minutes, create a new one
            if not existing_connection:
                Connection.objects.create(user=request.user, status='Online', date=current_datetime)

        return response
